@@ -859,7 +859,7 @@ void App_Glom::new_instance(const Glib::ustring& uri) //Override
 {
   Glib::ustring command = "glom";
   if(!uri.empty())
-    command += " " + uri;
+    command += ' ' + uri;
 
   GError* gerror = 0;
   gdk_spawn_command_line_on_screen(Glib::unwrap(get_screen()),
@@ -892,6 +892,11 @@ void App_Glom::init_create_document()
 
 bool App_Glom::check_document_hosting_mode_is_supported(Document* document)
 {
+  //If it's an example then the document's hosting mode doesn't matter, 
+  //because the user will be asked to choose one when saving anyway.
+  if(document->get_is_example_file())
+    return true;
+
   //Check that the file's hosting mode is supported by this build:
   Glib::ustring error_message;
   switch(document->get_hosting_mode())
