@@ -33,6 +33,7 @@
 
 #ifdef GLOM_ENABLE_MAEMO
 #include <hildon-fmmm/file-chooser-dialog.h>
+#include <hildon/hildon-window.h>
 #endif // GLOM_ENABLE_MAEMO
 
 #include <glibmm/i18n-lib.h>
@@ -67,6 +68,11 @@ App_WithDoc_Gtk::App_WithDoc_Gtk(BaseObjectType* cobject, const Glib::ustring& a
 {
   init_app_name(appname);
 
+  #ifdef GLOM_ENABLE_MAEMO
+  //The .glade file needs to specify HildonWindow or features such as HildonAppMenu won't work.
+  g_assert(HILDON_IS_WINDOW(gobj()));
+  #endif //GLOM_ENABLE_MAEMO
+
 #ifndef GLIBMM_DEFAULT_SIGNAL_HANDLERS_ENABLED
   signal_hide().connect(sigc::mem_fun(*this, &App_WithDoc_Gtk::on_hide));
   signal_delete_event().connect(sigc::mem_fun(*this, &App_WithDoc_Gtk::on_delete_event));
@@ -154,7 +160,7 @@ void App_WithDoc_Gtk::add_ui_from_string(const Glib::ustring& ui_description)
 #else
   std::auto_ptr<Glib::Error> error;
   m_refUIManager->add_ui_from_string(ui_description, error);
-  if(error.get() != NULL) std::cerr << "building menus failed: " << error->what();
+  if(error.get()) std::cerr << "building menus failed: " << error->what();
 #endif
 }
 
@@ -471,22 +477,22 @@ void App_WithDoc_Gtk::update_window_title()
 {
   //Set application's main window title:
 
-  Glib::ustring strTitle = m_strAppName;
   Document* pDoc = get_document();
-  if(pDoc)
-  {
-    strTitle += " - " + pDoc->get_name();
+  if(!pDoc)
+    return;
 
-    //Indicate unsaved changes:
-    if(pDoc->get_modified())
-      strTitle += " *";
+  Glib::ustring strTitle = m_strAppName;
+  strTitle += " - " + pDoc->get_name();
 
-    //Indicate read-only files:
-    if(pDoc->get_read_only())
-      strTitle += _(" (read-only)");
+  //Indicate unsaved changes:
+  if(pDoc->get_modified())
+    strTitle += " *";
 
-    set_title(strTitle);
-  }
+  //Indicate read-only files:
+  if(pDoc->get_read_only())
+    strTitle += _(" (read-only)");
+
+  set_title(strTitle);
 }
 
 void App_WithDoc_Gtk::ui_warning(const Glib::ustring& text, const Glib::ustring& secondary_text)
@@ -662,15 +668,14 @@ Glib::ustring App_WithDoc_Gtk::ui_file_select_save(const Glib::ustring& old_file
 
 void App_WithDoc_Gtk::ui_show_modification_status()
 {
-  bool modified = m_pDocument->get_modified();
+  const bool modified = m_pDocument->get_modified();
 
   //Enable Save and SaveAs menu items:
   if(m_action_save)
-    g_object_set(G_OBJECT(m_action_save->gobj()), "sensitive", modified, NULL); // TODO: Use a set_sensitive(modified)?
+    m_action_save->set_sensitive(modified);
 
   if(m_action_saveas)
-    g_object_set(G_OBJECT(m_action_saveas->gobj()), "sensitive", modified, NULL); // TODO: Use a set_sensitive(modified)?
-
+    m_action_saveas->set_sensitive(modified);
 }
 
 App_WithDoc_Gtk::enumSaveChanges App_WithDoc_Gtk::ui_offer_to_save_changes()
