@@ -19,7 +19,7 @@
  */
 
 #include <glom/mode_data/box_data_calendar_related.h>
-#include <glom/mode_data/dialog_layout_calendar_related.h>
+#include <glom/mode_design/layout/dialog_layout_calendar_related.h>
 #include <glom/utils_ui.h>
 #include <glom/application.h>
 #include <libglom/data_structure/glomconversions.h>
@@ -202,14 +202,26 @@ bool Box_Data_Calendar_Related::fill_from_database()
        continue;
        
       //Get the date value for this row:
-      Gnome::Gda::Value value_date = datamodel->get_value_at(m_query_column_date_field, row_index);     
+#ifdef GLIBMM_EXCEPTIONS_ENABLED      
+      Gnome::Gda::Value value_date = datamodel->get_value_at(m_query_column_date_field, row_index);
+#else
+      std::auto_ptr<Glib::Error> error;      
+      Gnome::Gda::Value value_date = datamodel->get_value_at(m_query_column_date_field, row_index, error);
+#endif      
       const Glib::Date date = value_date.get_date();
       
       //Get all the values for this row:
       type_vector_values* pVector = new type_vector_values(m_FieldsShown.size());
       for(int column_index = 0; column_index < columns_count; ++column_index)
       {
+#ifdef GLIBMM_EXCEPTIONS_ENABLED 
         (*pVector)[column_index] = datamodel->get_value_at(column_index, row_index);
+#else
+        std::auto_ptr<Glib::Error> error;      
+          (*pVector)[column_index] = datamodel->get_value_at(column_index, row_index, error);
+        if (error.get())
+          break;
+#endif 
       }
       
       m_map_values[date].push_back(pVector);
@@ -319,7 +331,7 @@ Box_Data_Calendar_Related::type_vecLayoutFields Box_Data_Calendar_Related::get_f
 void Box_Data_Calendar_Related::on_dialog_layout_hide()
 {
   Dialog_Layout_Calendar_Related* dialog_related = dynamic_cast<Dialog_Layout_Calendar_Related*>(m_pDialogLayout);
-  g_assert(dialog_related != NULL);
+  g_assert(dialog_related);
   m_portal = dialog_related->get_portal_layout();
 
 
@@ -344,7 +356,9 @@ void Box_Data_Calendar_Related::on_dialog_layout_hide()
 #ifndef GLOM_ENABLE_CLIENT_ONLY
 Dialog_Layout* Box_Data_Calendar_Related::create_layout_dialog() const
 {
-  Glib::RefPtr<Gtk::Builder> refXml = Gtk::Builder::create_from_file(GLOM_GLADEDIR "glom_developer.glade", "window_data_layout");
+  Glib::RefPtr<Gtk::Builder> refXml = Gtk::Builder::create_from_file(
+      GLOM_PKGDATADIR G_DIR_SEPARATOR_S "glade" G_DIR_SEPARATOR_S "glom_developer.glade",
+      "window_data_layout");
   if(refXml)
   {
     Dialog_Layout_Calendar_Related* dialog = 0;
@@ -352,13 +366,13 @@ Dialog_Layout* Box_Data_Calendar_Related::create_layout_dialog() const
     return dialog;
   }
 
-  return NULL;
+  return 0;
 }
 
 void Box_Data_Calendar_Related::prepare_layout_dialog(Dialog_Layout* dialog)
 {
   Dialog_Layout_Calendar_Related* related_dialog = dynamic_cast<Dialog_Layout_Calendar_Related*>(dialog);
-  g_assert(related_dialog != NULL);
+  g_assert(related_dialog);
   
   sharedptr<LayoutItem_CalendarPortal> derived_portal = sharedptr<LayoutItem_CalendarPortal>::cast_dynamic(m_portal);
   if(derived_portal && derived_portal->get_has_relationship_name())
@@ -461,7 +475,7 @@ Glib::ustring Box_Data_Calendar_Related::on_calendar_details(guint year, guint m
     if(!row_text.empty())
     {
       if(!result.empty())
-        result += "\n";
+        result += '\n';
       
       result += row_text;
     }
@@ -527,7 +541,7 @@ void Box_Data_Calendar_Related::setup_menu()
 #else
   std::auto_ptr<Glib::Error> error;
   m_refUIManager->add_ui_from_string(ui_info, error);
-  if(error.get() != NULL)
+  if(error.get())
   {
     std::cerr << "building menus failed: " << error->what();
   }
@@ -611,8 +625,5 @@ void Box_Data_Calendar_Related::set_primary_key_value(const Gtk::TreeModel::iter
 {
   //TODO
 }
-    
-
-
 
 } //namespace Glom
