@@ -69,11 +69,18 @@ public:
   void show_layout_toolbar(bool show = true);
 #endif
 
+  #ifdef GLOM_ENABLE_MAEMO
+  void do_new_record();
+  #endif
+
 protected:
 
 
   //Implementations of pure virtual methods from Base_DB_Table_Data:
+public:
   virtual Gnome::Gda::Value get_primary_key_value_selected() const; //Value in the primary key's cell.
+  
+protected:
   virtual void set_primary_key_value(const Gtk::TreeModel::iterator& row, const Gnome::Gda::Value& value);
   virtual Gnome::Gda::Value get_primary_key_value(const Gtk::TreeModel::iterator& row) const; //Actual primary key value of this record.
     
@@ -90,11 +97,12 @@ protected:
   void set_found_set_from_primary_key_value();
 
   void print_layout_group(xmlpp::Element* node_parent, const sharedptr<const LayoutGroup>& group);
-
+  
 private:
   //Signal handlers:
-#ifndef GLOM_ENABLE_MAEMO
   void on_button_new();
+    
+#ifndef GLOM_ENABLE_MAEMO
   void on_button_del();
 
   void on_button_nav_first();
