@@ -215,18 +215,21 @@ private:
 
 #ifndef GLOM_ENABLE_CLIENT_ONLY
 
-  virtual void on_dnd_add_placeholder(LayoutWidgetBase* above);
+  virtual void on_dnd_add_layout_item_by_type(int item_type_num, Gtk::Widget* above);
+  virtual void on_dnd_add_placeholder(Gtk::Widget* above);
   virtual void on_dnd_remove_placeholder();
+  virtual void set_child_widget_dnd_in_progress(Gtk::Widget* child, bool in_progress);
+  virtual bool get_child_widget_dnd_in_progress(Gtk::Widget* child) const;
     
-  // Methods for the different layout object
-  virtual void on_dnd_add_layout_item_field(LayoutWidgetBase* above);
-  virtual void on_dnd_add_layout_group(LayoutWidgetBase* above);
-  virtual void on_dnd_add_layout_item_button(LayoutWidgetBase* above);
-  virtual void on_dnd_add_layout_item_text(LayoutWidgetBase* above);
-  virtual void on_dnd_add_layout_item_image(LayoutWidgetBase* above);
-  virtual void on_dnd_add_layout_notebook(LayoutWidgetBase* above);
-  virtual void on_dnd_add_layout_portal(LayoutWidgetBase* above);
-  virtual void on_dnd_add_layout_item(LayoutWidgetBase* above, const sharedptr<LayoutItem>& item);
+  
+  void on_dnd_add_layout_item_field(LayoutWidgetBase* above);
+  void on_dnd_add_layout_group(LayoutWidgetBase* above);
+  void on_dnd_add_layout_item_button(LayoutWidgetBase* above);
+  void on_dnd_add_layout_item_text(LayoutWidgetBase* above);
+  void on_dnd_add_layout_item_image(LayoutWidgetBase* above);
+  void on_dnd_add_layout_notebook(LayoutWidgetBase* above);
+  void on_dnd_add_layout_portal(LayoutWidgetBase* above);
+  void on_dnd_add_layout_item(LayoutWidgetBase* above, const sharedptr<LayoutItem>& item);
   
   sharedptr<LayoutItem_Portal> get_portal_relationship();
 
