@@ -165,6 +165,9 @@ void Dialog_FieldDefinition::set_field(const sharedptr<const Field>& field, cons
   field_default_value->set_title(_("Default Value"));
   layout_item->set_full_field_details(field_default_value);
   m_pDataWidget_DefaultValueSimple = Gtk::manage( new DataWidget(layout_item, "", get_document()) );
+  if(!m_pDataWidget_DefaultValueSimple->get_data_child_widget())
+    std::cerr << "Dialog_FieldDefinition::set_field(): The DataWidget did not create a child widget." << std::endl;
+
   on_foreach_connect(*m_pDataWidget_DefaultValueSimple);
 
   Gtk::Label* pLabel = m_pDataWidget_DefaultValueSimple->get_label();
