@@ -24,9 +24,9 @@
 #include "config.h" // For GLOM_ENABLE_CLIENT_ONLY
 
 #include <gtkmm.h>
-#include <glom/libglom/data_structure/field.h>
+#include <libglom/data_structure/field.h>
 #include "layoutwidgetfield.h"
-#include <libglademm.h>
+#include <gtkmm/builder.h>
 
 namespace Glom
 {
@@ -44,7 +44,7 @@ public:
   virtual void set_value(const Gnome::Gda::Value& value);
   virtual Gnome::Gda::Value get_value() const;    
 
-protected:
+private:
   void init();
 
 #ifndef GLOM_ENABLE_CLIENT_ONLY
