@@ -191,9 +191,6 @@ public:
   type_vec_strings get_columns_order() const;
 
   void remove_all_columns();
-  //virtual void set_columns_count(guint count);
-  //virtual void set_column_title(guint col, const Glib::ustring& strText);
-  void set_column_width(guint col, guint width);
 
   /// For popup cells.
   void set_column_choices(guint col, const type_vec_strings& vecStrings);
@@ -259,6 +256,12 @@ public:
   virtual Gtk::TreeModel::iterator get_last_row() const;
 
   virtual void set_open_button_title(const Glib::ustring& title);
+  
+  
+  /** Add a new row to the list, for the user to enter record details,
+   * adding the generated primary key if necessary.
+   */
+  bool start_new_record();
 
 private:
   
@@ -302,6 +305,7 @@ private:
   //Signal handlers:
   #ifdef GLOM_ENABLE_MAEMO
   void treeviewcolumn_on_cell_data(const Gtk::TreeModel::iterator& iter, int model_column_index, int data_model_column_index);
+  void on_maemo_touchselector_changed(int column);
   #else
   void treeviewcolumn_on_cell_data(Gtk::CellRenderer* renderer, const Gtk::TreeModel::iterator& iter, int model_column_index, int data_model_column_index);
   #endif //GLOM_ENABLE_MAEMO
@@ -366,7 +370,7 @@ private:
   guint get_count_hidden_system_columns() const;
 
   //The column_id is extra information that we can use later to discover what the column shows, even when columns have been reordered.
-  guint treeview_append_column(const Glib::ustring& title, Gtk::CellRenderer& cellrenderer, int model_column_index, int data_model_column_index);
+  guint treeview_append_column(const Glib::ustring& title, Gtk::CellRenderer& cellrenderer, int model_column_index, int data_model_column_index, bool expand);
 
   /** Show a model that gives a visual hint to the developer,
    * when he has not yet specified fields to show.
@@ -429,7 +433,7 @@ private:
   bool m_bIgnoreTreeViewSignals;
 
   type_vec_strings m_vecColumnIDs; //We give each ViewColumn a special ID, so we know where they are after a reorder.
-
+  
 protected:
   bool m_allow_add;
   bool m_allow_delete;
@@ -503,12 +507,13 @@ private:
   Glib::RefPtr<Gtk::ListStore> m_model_hint;
 
   int m_fixed_cell_height;
-    
-    
+  
 private:
   
+  /// Discover the right-most text column, so we can make it expand.
+  bool get_column_to_expand(guint& column_to_expand) const;
+  
   //TODO_refactor: Give these better names, and document them:
-  bool start_new_record();
   void user_changed(const Gtk::TreeModel::iterator& row, guint col);
   void user_requested_delete(const Gtk::TreeModel::iterator& rowStart, const Gtk::TreeModel::iterator&  /* rowEnd TODO */);
 
